@@ -50,6 +50,7 @@ def write_default_ansible_cfg(work_dir,
                os.path.join(work_dir, 'ansible.log'))
     config.set('defaults', 'forks', '25')
     config.set('defaults', 'timeout', '30')
+    config.set('defaults', 'gather_timeout', '30')
 
     # mistral user has no home dir set, so no place to save a known hosts file
     config.set('ssh_connection', 'ssh_args',
@@ -318,6 +319,8 @@ class AnsiblePlaybookAction(base.TripleOAction):
             'blacklisted_hostnames', [])
         self.override_ansible_cfg = self._kwargs_for_run.pop(
             'override_ansible_cfg', None)
+        self.command_timeout = self._kwargs_for_run.pop(
+            'command_timeout', None)
 
     @property
     def work_dir(self):
@@ -525,6 +528,9 @@ class AnsiblePlaybookAction(base.TripleOAction):
                     'OS_AUTH_TOKEN': security_ctx.auth_token,
                     'OS_PROJECT_NAME': security_ctx.project_name})
 
+            if self.command_timeout:
+                command = ['timeout', self.command_timeout] + command
+
             command = [str(c) for c in command]
 
             if self.reproduce_command:
@@ -551,13 +557,15 @@ class AnsiblePlaybookAction(base.TripleOAction):
                                            stderr=subprocess.STDOUT,
                                            shell=False, bufsize=1,
                                            cwd=self.work_dir,
-                                           env=env_variables)
+                                           env=env_variables,
+                                           universal_newlines=True)
                 start = time.time()
                 stdout = []
                 lines = []
                 for line in iter(process.stdout.readline, b''):
                     lines.append(line)
-                    stdout.append(line)
+                    if not self.trash_output:
+                        stdout.append(line)
                     if time.time() - start > 30:
                         self.post_message(queue, ''.join(lines))
                         lines = []
@@ -569,9 +577,6 @@ class AnsiblePlaybookAction(base.TripleOAction):
                 # stdout we don't know the difference. To keep the return dict
                 # similar there is an empty stderr. We can use the return code
                 # to determine if there was an error.
-                if self.trash_output:
-                    stdout = []
-                    stderr = ""
                 return {"stdout": "".join(stdout), "returncode": returncode,
                         "stderr": ""}
 
@@ -596,6 +601,8 @@ class AnsibleGenerateInventoryAction(base.TripleOAction):
         self._kwargs_for_run = kwargs
         self.ansible_ssh_user = self._kwargs_for_run.pop(
             'ansible_ssh_user', 'tripleo-admin')
+        self.ansible_python_interpreter = self._kwargs_for_run.pop(
+            'ansible_python_interpreter', None)
         self._work_dir = self._kwargs_for_run.pop(
             'work_dir', None)
         self.plan_name = self._kwargs_for_run.pop(
@@ -623,6 +630,7 @@ class AnsibleGenerateInventoryAction(base.TripleOAction):
             project_name=context.security.project_name,
             username=context.security.user_name,
             ansible_ssh_user=self.ansible_ssh_user,
+            ansible_python_interpreter=self.ansible_python_interpreter,
             plan_name=self.plan_name,
             host_network=self.ssh_network)
 
