@@ -27,42 +27,37 @@ import yaml
 from tripleo_common.image import base
 from tripleo_common.image import image_uploader
 
-CONTAINER_IMAGE_PREPARE_PARAM = [{
-    'tag_from_label': 'rdo_version',
-    'set': {
-        'namespace': 'docker.io/tripleomaster',
-        'ceph_namespace': 'docker.io/ceph',
-        'ceph_image': 'daemon',
-        'ceph_tag': 'v3.1.0-stable-3.1-luminous-centos-7-x86_64',
-        'name_prefix': 'centos-binary-',
-        'name_suffix': '',
-        'tag': 'current-tripleo',
-        'neutron_driver': None,
-        'openshift_namespace': 'docker.io/openshift',
-        'openshift_tag': 'v3.10.0',
-        'openshift_base_image': 'origin',
-        'openshift_cockpit_namespace': 'docker.io/cockpit',
-        'openshift_cockpit_image': 'kubernetes',
-        'openshift_cockpit_tag': 'latest',
-        'openshift_etcd_namespace': 'registry.fedoraproject.org/latest',
-        'openshift_etcd_image': 'etcd',
-        'openshift_etcd_tag': 'latest',
-        'openshift_gluster_namespace': 'docker.io/gluster',
-        'openshift_gluster_image': 'gluster-centos',
-        'openshift_gluster_block_image': 'glusterblock-provisioner',
-        'openshift_gluster_tag': 'latest',
-        'openshift_heketi_namespace': 'docker.io/heketi',
-        'openshift_heketi_image': 'heketi',
-        'openshift_heketi_tag': 'latest',
-    }
-}]
+CONTAINER_IMAGE_PREPARE_PARAM_STR = None
 
-CONTAINER_IMAGES_DEFAULTS = CONTAINER_IMAGE_PREPARE_PARAM[0]['set']
+CONTAINER_IMAGE_PREPARE_PARAM = None
+
+CONTAINER_IMAGES_DEFAULTS = None
+
+
+def init_prepare_defaults(defaults_file):
+    global CONTAINER_IMAGE_PREPARE_PARAM_STR
+    with open(defaults_file) as f:
+        CONTAINER_IMAGE_PREPARE_PARAM_STR = f.read()
+
+    global CONTAINER_IMAGE_PREPARE_PARAM
+    p = yaml.safe_load(CONTAINER_IMAGE_PREPARE_PARAM_STR)
+    CONTAINER_IMAGE_PREPARE_PARAM = p[
+        'parameter_defaults']['ContainerImagePrepare']
+
+    global CONTAINER_IMAGES_DEFAULTS
+    CONTAINER_IMAGES_DEFAULTS = CONTAINER_IMAGE_PREPARE_PARAM[0]['set']
 
 DEFAULT_TEMPLATE_FILE = os.path.join(sys.prefix, 'share', 'tripleo-common',
                                      'container-images',
                                      'overcloud_containers.yaml.j2')
 
+DEFAULT_PREPARE_FILE = os.path.join(sys.prefix, 'share', 'tripleo-common',
+                                    'container-images',
+                                    'container_image_prepare_defaults.yaml')
+
+if os.path.isfile(DEFAULT_PREPARE_FILE):
+    init_prepare_defaults(DEFAULT_PREPARE_FILE)
+
 
 def get_enabled_services(environment, roles_data):
     """Build list of enabled services
@@ -146,6 +141,11 @@ def container_images_prepare_multi(environment, roles_data, dry_run=False,
     if not cip:
         return
 
+    mirrors = {}
+    mirror = pd.get('DockerRegistryMirror')
+    if mirror:
+        mirrors['docker.io'] = mirror
+
     env_params = {}
     service_filter = build_service_filter(environment, roles_data)
 
@@ -181,6 +181,7 @@ def container_images_prepare_multi(environment, roles_data, dry_run=False,
             modify_role=modify_role,
             modify_vars=modify_vars,
             modify_only_with_labels=modify_only_with_labels,
+            mirrors=mirrors
         )
         env_params.update(prepare_data['image_params'])
 
@@ -191,9 +192,9 @@ def container_images_prepare_multi(environment, roles_data, dry_run=False,
                 }, f)
                 uploader = image_uploader.ImageUploadManager(
                     [f.name],
-                    verbose=True,
                     dry_run=dry_run,
-                    cleanup=cleanup
+                    cleanup=cleanup,
+                    mirrors=mirrors
                 )
                 uploader.upload()
     return env_params
@@ -215,7 +216,8 @@ def container_images_prepare(template_file=DEFAULT_TEMPLATE_FILE,
                              mapping_args=None, output_env_file=None,
                              output_images_file=None, tag_from_label=None,
                              append_tag=None, modify_role=None,
-                             modify_vars=None, modify_only_with_labels=None):
+                             modify_vars=None, modify_only_with_labels=None,
+                             mirrors=None):
     """Perform container image preparation
 
     :param template_file: path to Jinja2 file containing all image entries
@@ -241,6 +243,7 @@ def container_images_prepare(template_file=DEFAULT_TEMPLATE_FILE,
     :param modify_vars: dict of variables to pass to modify_role
     :param modify_only_with_labels: only modify the container images with the
                                     given labels
+    :param mirrors: dict of registry netloc values to mirror urls
     :returns: dict with entries for the supplied output_env_file or
               output_images_file
     """
@@ -275,7 +278,7 @@ def container_images_prepare(template_file=DEFAULT_TEMPLATE_FILE,
 
     if tag_from_label:
         image_version_tags = uploader.discover_image_tags(
-            images, tag_from_label)
+            images, tag_from_label, mirrors=mirrors)
         for entry in result:
             imagename = entry.get('imagename', '')
             image_no_tag = imagename.rpartition(':')[0]
@@ -285,7 +288,7 @@ def container_images_prepare(template_file=DEFAULT_TEMPLATE_FILE,
 
     if modify_only_with_labels:
         images_with_labels = uploader.filter_images_with_labels(
-            images, modify_only_with_labels)
+            images, modify_only_with_labels, mirrors=mirrors)
 
     params = {}
     modify_append_tag = append_tag
@@ -428,7 +431,7 @@ class KollaImageBuilder(base.BaseImageManager):
                 result.append(entry)
         return result
 
-    def build_images(self, kolla_config_files=None):
+    def build_images(self, kolla_config_files=None, excludes=[]):
 
         cmd = ['kolla-build']
         if kolla_config_files:
@@ -439,13 +442,19 @@ class KollaImageBuilder(base.BaseImageManager):
         container_images = self.load_config_files(self.CONTAINER_IMAGES) or []
         container_images.sort(key=lambda i: i.get('imagename'))
         for i in container_images:
+            # Do not attempt to build containers that are not from kolla or
+            # are in our exclude list
+            if not i.get('image_source', '') == 'kolla':
+                continue
             image = self.imagename_to_regex(i.get('imagename'))
-            if image:
+            # Make sure the image was properly parsed and not purposely skipped
+            if image and image not in excludes:
                 cmd.append(image)
 
         self.logger.info('Running %s' % ' '.join(cmd))
         env = os.environ.copy()
-        process = subprocess.Popen(cmd, env=env, stdout=subprocess.PIPE)
+        process = subprocess.Popen(cmd, env=env, stdout=subprocess.PIPE,
+                                   universal_newlines=True)
         out, err = process.communicate()
         if process.returncode != 0:
             raise subprocess.CalledProcessError(process.returncode, cmd, err)
