@@ -17,6 +17,7 @@
 
 from collections import OrderedDict
 import os.path
+import sys
 import yaml
 
 from heatclient.exc import HTTPNotFound
@@ -83,30 +84,21 @@ class StackOutputs(object):
 
 
 class TripleoInventory(object):
-    def __init__(self, configs=None, session=None, hclient=None,
+    def __init__(self, session=None, hclient=None,
                  plan_name=None, auth_url=None, project_name=None,
                  cacert=None, username=None, ansible_ssh_user=None,
-                 host_network=None):
+                 host_network=None, ansible_python_interpreter=None):
         self.session = session
         self.hclient = hclient
         self.hosts_format_dict = False
         self.host_network = host_network or HOST_NETWORK
-        if configs is not None:
-            # FIXME(shardy) backwards compatibility until we switch
-            # tripleo-validations to pass the individual values
-            self.auth_url = configs.auth_url
-            self.cacert = configs.cacert
-            self.project_name = configs.project_name
-            self.username = configs.username
-            self.ansible_ssh_user = configs.ansible_ssh_user
-            self.plan_name = configs.plan
-        else:
-            self.auth_url = auth_url
-            self.cacert = cacert
-            self.project_name = project_name
-            self.username = username
-            self.ansible_ssh_user = ansible_ssh_user
-            self.plan_name = plan_name
+        self.auth_url = auth_url
+        self.cacert = cacert
+        self.project_name = project_name
+        self.username = username
+        self.ansible_ssh_user = ansible_ssh_user
+        self.plan_name = plan_name
+        self.ansible_python_interpreter = ansible_python_interpreter
         self.stack_outputs = StackOutputs(self.plan_name, self.hclient)
         self.hostvars = {}
 
@@ -159,6 +151,7 @@ class TripleoInventory(object):
                 'vars': {
                     'ansible_host': 'localhost',
                     'ansible_connection': 'local',
+                    'ansible_python_interpreter': sys.executable,
                     # see https://github.com/ansible/ansible/issues/41808
                     'ansible_remote_tmp': '/tmp/ansible-${USER}',
                     'auth_url': self.auth_url,
@@ -172,6 +165,10 @@ class TripleoInventory(object):
             }
         })
 
+        if self.ansible_python_interpreter:
+            ret['Undercloud']['vars']['ansible_python_interpreter'] = \
+                self.ansible_python_interpreter
+
         swift_url = None
         if self.session:
             swift_url = self.session.get_endpoint(service_type='object-store',
@@ -248,6 +245,10 @@ class TripleoInventory(object):
 
                 }
 
+                if self.ansible_python_interpreter:
+                    ret[role]['vars']['ansible_python_interpreter'] = \
+                        self.ansible_python_interpreter
+
                 self.hostvars.update(hosts)
 
         if children:
@@ -273,6 +274,9 @@ class TripleoInventory(object):
                         'ansible_ssh_user': self.ansible_ssh_user
                     }
                 }
+                if self.ansible_python_interpreter:
+                    ret[role]['vars']['ansible_python_interpreter'] = \
+                        self.ansible_python_interpreter
 
         if not self.hosts_format_dict:
             # Prevent Ansible from repeatedly calling us to get empty host
