@@ -24,6 +24,7 @@ import tempfile
 import yaml
 
 from tripleo_common import constants
+from tripleo_common.image import image_uploader
 from tripleo_common.image import kolla_builder as kb
 from tripleo_common.tests import base
 
@@ -33,28 +34,48 @@ TEMPLATE_PATH = os.path.join(os.path.dirname(__file__),
                              'overcloud_containers.yaml.j2')
 
 
+DEFAULTS_PATH = os.path.join(os.path.dirname(__file__),
+                             '..', '..', '..', 'container-images',
+                             'container_image_prepare_defaults.yaml')
+kb.init_prepare_defaults(DEFAULTS_PATH)
+
+
 filedata = six.u("""container_images:
 - imagename: docker.io/tripleomaster/heat-docker-agents-centos:latest
+  image_source: kolla
   push_destination: localhost:8787
 - imagename: docker.io/tripleomaster/centos-binary-nova-compute:liberty
+  image_source: kolla
   uploader: docker
   push_destination: localhost:8787
 - imagename: docker.io/tripleomaster/centos-binary-nova-libvirt:liberty
+  image_source: kolla
   uploader: docker
 - imagename: docker.io/tripleomaster/image-with-missing-tag
+  image_source: kolla
+  push_destination: localhost:8787
+- imagename: docker.io/tripleomaster/skip-build
+  image_source: foo
   push_destination: localhost:8787
 """)
 
 template_filedata = six.u("""
 container_images_template:
 - imagename: "{{namespace}}/heat-docker-agents-centos:latest"
+  image_source: kolla
   push_destination: "{{push_destination}}"
 - imagename: "{{namespace}}/{{name_prefix}}nova-compute{{name_suffix}}:{{tag}}"
+  image_source: kolla
   uploader: "docker"
   push_destination: "{{push_destination}}"
 - imagename: "{{namespace}}/{{name_prefix}}nova-libvirt{{name_suffix}}:{{tag}}"
+  image_source: kolla
   uploader: "docker"
 - imagename: "{{namespace}}/image-with-missing-tag"
+  image_source: kolla
+  push_destination: "{{push_destination}}"
+- imagename: "{{namespace}}/skip-build"
+  image_source: foo
   push_destination: "{{push_destination}}"
 """)
 
@@ -101,7 +122,7 @@ class TestKollaImageBuilder(base.TestCase):
             'nova-libvirt',
             'heat-docker-agents-centos',
             'image-with-missing-tag',
-        ], env=env, stdout=-1)
+        ], env=env, stdout=-1, universal_newlines=True)
 
     @mock.patch('subprocess.Popen')
     def test_build_images_no_conf(self, mock_popen):
@@ -115,7 +136,30 @@ class TestKollaImageBuilder(base.TestCase):
         env = os.environ.copy()
         mock_popen.assert_called_once_with([
             'kolla-build',
-        ], env=env, stdout=-1)
+        ], env=env, stdout=-1, universal_newlines=True)
+
+    @mock.patch('tripleo_common.image.base.open',
+                mock.mock_open(read_data=filedata), create=True)
+    @mock.patch('os.path.isfile', return_value=True)
+    @mock.patch('subprocess.Popen')
+    def test_build_images_exclude(self, mock_popen, mock_path):
+        process = mock.Mock()
+        process.returncode = 0
+        process.communicate.return_value = 'done', ''
+        mock_popen.return_value = process
+
+        builder = kb.KollaImageBuilder(self.filelist)
+        self.assertEqual('done', builder.build_images(['kolla-config.conf'],
+                                                      ['nova-compute']))
+        env = os.environ.copy()
+        mock_popen.assert_called_once_with([
+            'kolla-build',
+            '--config-file',
+            'kolla-config.conf',
+            'nova-libvirt',
+            'heat-docker-agents-centos',
+            'image-with-missing-tag',
+        ], env=env, stdout=-1, universal_newlines=True)
 
     @mock.patch('subprocess.Popen')
     def test_build_images_fail(self, mock_popen):
@@ -131,7 +175,7 @@ class TestKollaImageBuilder(base.TestCase):
         env = os.environ.copy()
         mock_popen.assert_called_once_with([
             'kolla-build',
-        ], env=env, stdout=-1)
+        ], env=env, stdout=-1, universal_newlines=True)
 
 
 class TestKollaImageBuilderTemplate(base.TestCase):
@@ -167,14 +211,14 @@ class TestKollaImageBuilderTemplate(base.TestCase):
                 'namespace': 'docker.io/tripleomaster',
                 'ceph_namespace': 'docker.io/ceph',
                 'ceph_image': 'daemon',
-                'ceph_tag': 'v3.1.0-stable-3.1-luminous-centos-7-x86_64',
+                'ceph_tag': 'v3.2.0-stable-3.2-luminous-centos-7-x86_64',
                 'name_prefix': 'centos-binary-',
                 'name_suffix': '',
                 'tag': 'current-tripleo',
                 'neutron_driver': None,
                 'openshift_namespace': 'docker.io/openshift',
-                'openshift_tag': 'v3.10.0',
-                'openshift_base_image': 'origin',
+                'openshift_tag': 'v3.11.0',
+                'openshift_prefix': 'origin',
                 'openshift_cockpit_namespace': 'docker.io/cockpit',
                 'openshift_cockpit_image': 'kubernetes',
                 'openshift_cockpit_tag': 'latest',
@@ -189,6 +233,33 @@ class TestKollaImageBuilderTemplate(base.TestCase):
                 'openshift_heketi_namespace': 'docker.io/heketi',
                 'openshift_heketi_image': 'heketi',
                 'openshift_heketi_tag': 'latest',
+                'openshift_cluster_monitoring_namespace': 'quay.io/coreos',
+                'openshift_cluster_monitoring_image':
+                    'cluster-monitoring-operator',
+                'openshift_cluster_monitoring_tag': 'v0.1.1',
+                'openshift_configmap_reload_namespace': 'quay.io/coreos',
+                'openshift_configmap_reload_image': 'configmap-reload',
+                'openshift_configmap_reload_tag': 'latest',
+                'openshift_prometheus_operator_namespace': 'quay.io/coreos',
+                'openshift_prometheus_operator_image': 'prometheus-operator',
+                'openshift_prometheus_operator_tag': 'latest',
+                'openshift_prometheus_config_reload_namespace':
+                    'quay.io/coreos',
+                'openshift_prometheus_config_reload_image':
+                    'prometheus-config-reloader',
+                'openshift_prometheus_config_reload_tag': 'v0.24.0',
+                'openshift_prometheus_tag': 'latest',
+                'openshift_prometheus_alertmanager_tag': 'latest',
+                'openshift_prometheus_node_exporter_tag': 'latest',
+                'openshift_oauth_proxy_tag': 'latest',
+                'openshift_kube_rbac_proxy_namespace': 'quay.io/coreos',
+                'openshift_kube_rbac_proxy_image': 'kube-rbac-proxy',
+                'openshift_kube_rbac_proxy_tag': 'v0.3.1',
+                'openshift_kube_state_metrics_namespace': 'quay.io/coreos',
+                'openshift_kube_state_metrics_image': 'kube-state-metrics',
+                'openshift_kube_state_metrics_tag': 'latest',
+                'openshift_grafana_namespace': 'docker.io/grafana',
+                'openshift_grafana_tag': 'latest',
             },
             builder.container_images_template_inputs()
         )
@@ -204,8 +275,8 @@ class TestKollaImageBuilderTemplate(base.TestCase):
                 'tag': 'master',
                 'neutron_driver': 'ovn',
                 'openshift_namespace': 'docker.io/openshift3',
-                'openshift_tag': 'v3.10.0',
-                'openshift_base_image': 'ose',
+                'openshift_tag': 'v3.11.0',
+                'openshift_prefix': 'ose',
                 'openshift_cockpit_namespace': 'docker.io/openshift-cockpit',
                 'openshift_cockpit_image': 'cockpit',
                 'openshift_cockpit_tag': 'cockpit-tag',
@@ -213,15 +284,49 @@ class TestKollaImageBuilderTemplate(base.TestCase):
                 'openshift_etcd_image': 'openshift-etcd',
                 'openshift_etcd_tag': 'etcd-tag',
                 'openshift_gluster_namespace':
-                'registry.access.redhat.com/rhgs3',
+                    'registry.access.redhat.com/rhgs3',
                 'openshift_gluster_image': 'rhgs-server-rhel7',
                 'openshift_gluster_block_image':
-                'rhgs-gluster-block-prov-rhel7',
+                    'rhgs-gluster-block-prov-rhel7',
                 'openshift_gluster_tag': 'gluster-tag',
                 'openshift_heketi_namespace':
-                'registry.access.redhat.com/rhgs3',
+                    'registry.access.redhat.com/rhgs3',
                 'openshift_heketi_image': 'rhgs-volmanager-rhel7',
                 'openshift_heketi_tag': 'heketi-tag',
+                'openshift_cluster_monitoring_namespace':
+                    'registry.access.redhat.com/openshift3',
+                'openshift_cluster_monitoring_image':
+                    'ose-cluster-monitoring-operator',
+                'openshift_cluster_monitoring_tag': 'v3.11',
+                'openshift_configmap_reload_namespace':
+                    'registry.access.redhat.com/openshift3',
+                'openshift_configmap_reload_image': 'ose-configmap-reloader',
+                'openshift_configmap_reload_tag': 'v3.11',
+                'openshift_prometheus_operator_namespace':
+                    'registry.access.redhat.com/openshift3',
+                'openshift_prometheus_operator_image':
+                    'ose-prometheus-operator',
+                'openshift_prometheus_operator_tag': 'v3.11',
+                'openshift_prometheus_config_reload_namespace':
+                    'registry.access.redhat.com/openshift3',
+                'openshift_prometheus_config_reload_image':
+                    'ose-prometheus-config-reloader',
+                'openshift_prometheus_config_reload_tag': 'v3.11',
+                'openshift_prometheus_tag': 'v3.11',
+                'openshift_prometheus_alertmanager_tag': 'v3.11',
+                'openshift_prometheus_node_exporter_tag': 'v3.11',
+                'openshift_oauth_proxy_tag': 'v3.11',
+                'openshift_kube_rbac_proxy_namespace':
+                    'registry.access.redhat.com/openshift3',
+                'openshift_kube_rbac_proxy_image': 'ose-kube-rbac-proxy',
+                'openshift_kube_rbac_proxy_tag': 'v3.11',
+                'openshift_kube_state_metrics_namespace':
+                    'registry.access.redhat.com/openshift3',
+                'openshift_kube_state_metrics_image': 'ose-kube-state-metrics',
+                'openshift_kube_state_metrics_tag': 'v3.11',
+                'openshift_grafana_namespace':
+                    'registry.access.redhat.com/openshift3',
+                'openshift_grafana_tag': 'v3.11',
             },
             builder.container_images_template_inputs(
                 namespace='192.0.2.0:5000/tripleomaster',
@@ -233,8 +338,8 @@ class TestKollaImageBuilderTemplate(base.TestCase):
                 tag='master',
                 neutron_driver='ovn',
                 openshift_namespace='docker.io/openshift3',
-                openshift_tag='v3.10.0',
-                openshift_base_image='ose',
+                openshift_tag='v3.11.0',
+                openshift_prefix='ose',
                 openshift_cockpit_namespace='docker.io/openshift-cockpit',
                 openshift_cockpit_image='cockpit',
                 openshift_cockpit_tag='cockpit-tag',
@@ -248,6 +353,40 @@ class TestKollaImageBuilderTemplate(base.TestCase):
                 openshift_heketi_namespace='registry.access.redhat.com/rhgs3',
                 openshift_heketi_image='rhgs-volmanager-rhel7',
                 openshift_heketi_tag='heketi-tag',
+                openshift_cluster_monitoring_namespace='registry.'
+                    'access.redhat.com/openshift3',
+                openshift_cluster_monitoring_image='ose-'
+                    'cluster-monitoring-operator',
+                openshift_cluster_monitoring_tag='v3.11',
+                openshift_configmap_reload_namespace='registry.'
+                    'access.redhat.com/openshift3',
+                openshift_configmap_reload_image='ose-configmap-reloader',
+                openshift_configmap_reload_tag='v3.11',
+                openshift_prometheus_operator_namespace='registry.'
+                    'access.redhat.com/openshift3',
+                openshift_prometheus_operator_image='ose-'
+                    'prometheus-operator',
+                openshift_prometheus_operator_tag='v3.11',
+                openshift_prometheus_config_reload_namespace='registry.'
+                    'access.redhat.com/openshift3',
+                openshift_prometheus_config_reload_image='ose-'
+                    'prometheus-config-reloader',
+                openshift_prometheus_config_reload_tag='v3.11',
+                openshift_prometheus_tag='v3.11',
+                openshift_prometheus_alertmanager_tag='v3.11',
+                openshift_prometheus_node_exporter_tag='v3.11',
+                openshift_oauth_proxy_tag='v3.11',
+                openshift_kube_rbac_proxy_namespace='registry.'
+                    'access.redhat.com/openshift3',
+                openshift_kube_rbac_proxy_image='ose-kube-rbac-proxy',
+                openshift_kube_rbac_proxy_tag='v3.11',
+                openshift_kube_state_metrics_namespace='registry.'
+                    'access.redhat.com/openshift3',
+                openshift_kube_state_metrics_image='ose-kube-state-metrics',
+                openshift_kube_state_metrics_tag='v3.11',
+                openshift_grafana_namespace='registry.'
+                    'access.redhat.com/openshift3',
+                openshift_grafana_tag='v3.11',
             )
         )
 
@@ -269,18 +408,25 @@ class TestKollaImageBuilderTemplate(base.TestCase):
             tag='liberty'
         )
         container_images = [{
+            'image_source': 'kolla',
             'imagename': 'docker.io/tripleomaster/'
                          'centos-binary-nova-compute:liberty',
             'push_destination': 'localhost:8787',
             'uploader': 'docker'
         }, {
+            'image_source': 'kolla',
             'imagename': 'docker.io/tripleomaster/'
                          'centos-binary-nova-libvirt:liberty',
             'push_destination': 'localhost:8787',
             'uploader': 'docker'
         }, {
+            'image_source': 'kolla',
             'imagename': 'docker.io/tripleomaster/image-with-missing-tag',
             'push_destination': 'localhost:8787'
+        }, {
+            'image_source': 'foo',
+            'imagename': 'docker.io/tripleomaster/skip-build',
+            'push_destination': 'localhost:8787'
         }]
         self.assertEqual(container_images, result)
 
@@ -321,23 +467,32 @@ class TestKollaImageBuilderTemplate(base.TestCase):
 
     def test_container_images_yaml_in_sync(self):
         remove_images = [
-            {'imagename': 'docker.io/tripleomaster/centos-binary'
+            {'image_source': 'kolla',
+             'imagename': 'docker.io/tripleomaster/centos-binary'
                           '-neutron-server-opendaylight:current-tripleo'},
-            {'imagename': 'docker.io/tripleomaster/centos-binary'
+            {'image_source': 'kolla',
+             'imagename': 'docker.io/tripleomaster/centos-binary'
                           '-neutron-server-ovn:current-tripleo'},
-            {'imagename': 'docker.io/tripleomaster/centos-binary'
+            {'image_source': 'kolla',
+             'imagename': 'docker.io/tripleomaster/centos-binary'
                           '-ovn-base:current-tripleo'},
-            {'imagename': 'docker.io/tripleomaster/centos-binary'
+            {'image_source': 'kolla',
+             'imagename': 'docker.io/tripleomaster/centos-binary'
                           '-opendaylight:current-tripleo'},
-            {'imagename': 'docker.io/tripleomaster/centos-binary'
+            {'image_source': 'kolla',
+             'imagename': 'docker.io/tripleomaster/centos-binary'
                           '-ovn-northd:current-tripleo'},
-            {'imagename': 'docker.io/tripleomaster/centos-binary-ovn-'
+            {'image_source': 'kolla',
+             'imagename': 'docker.io/tripleomaster/centos-binary-ovn-'
                           'controller:current-tripleo'},
-            {'imagename': 'docker.io/tripleomaster/centos-binary-ovn-'
+            {'image_source': 'kolla',
+             'imagename': 'docker.io/tripleomaster/centos-binary-ovn-'
                           'nb-db-server:current-tripleo'},
-            {'imagename': 'docker.io/tripleomaster/centos-binary-ovn-'
+            {'image_source': 'kolla',
+             'imagename': 'docker.io/tripleomaster/centos-binary-ovn-'
                           'sb-db-server:current-tripleo'},
-            {'imagename': 'docker.io/tripleomaster/centos-binary'
+            {'image_source': 'kolla',
+             'imagename': 'docker.io/tripleomaster/centos-binary'
                           '-neutron-metadata-agent-ovn:current-tripleo'}]
         self._test_container_images_yaml_in_sync_helper(
             remove_images=remove_images)
@@ -345,21 +500,29 @@ class TestKollaImageBuilderTemplate(base.TestCase):
     def test_container_images_yaml_in_sync_for_odl(self):
         # remove neutron-server image reference from overcloud_containers.yaml
         remove_images = [
-            {'imagename': 'docker.io/tripleomaster/centos-binary'
+            {'image_source': 'kolla',
+             'imagename': 'docker.io/tripleomaster/centos-binary'
                           '-neutron-server:current-tripleo'},
-            {'imagename': 'docker.io/tripleomaster/centos-binary'
+            {'image_source': 'kolla',
+             'imagename': 'docker.io/tripleomaster/centos-binary'
                           '-neutron-server-ovn:current-tripleo'},
-            {'imagename': 'docker.io/tripleomaster/centos-binary'
+            {'image_source': 'kolla',
+             'imagename': 'docker.io/tripleomaster/centos-binary'
                           '-ovn-base:current-tripleo'},
-            {'imagename': 'docker.io/tripleomaster/centos-binary'
+            {'image_source': 'kolla',
+             'imagename': 'docker.io/tripleomaster/centos-binary'
                           '-ovn-northd:current-tripleo'},
-            {'imagename': 'docker.io/tripleomaster/centos-binary-ovn-'
+            {'image_source': 'kolla',
+             'imagename': 'docker.io/tripleomaster/centos-binary-ovn-'
                           'controller:current-tripleo'},
-            {'imagename': 'docker.io/tripleomaster/centos-binary-ovn-'
+            {'image_source': 'kolla',
+             'imagename': 'docker.io/tripleomaster/centos-binary-ovn-'
                           'nb-db-server:current-tripleo'},
-            {'imagename': 'docker.io/tripleomaster/centos-binary-ovn-'
+            {'image_source': 'kolla',
+             'imagename': 'docker.io/tripleomaster/centos-binary-ovn-'
                           'sb-db-server:current-tripleo'},
-            {'imagename': 'docker.io/tripleomaster/centos-binary'
+            {'image_source': 'kolla',
+             'imagename': 'docker.io/tripleomaster/centos-binary'
                           '-neutron-metadata-agent-ovn:current-tripleo'}]
         self._test_container_images_yaml_in_sync_helper(
             neutron_driver='odl', remove_images=remove_images)
@@ -367,11 +530,14 @@ class TestKollaImageBuilderTemplate(base.TestCase):
     def test_container_images_yaml_in_sync_for_ovn(self):
         # remove neutron-server image reference from overcloud_containers.yaml
         remove_images = [
-            {'imagename': 'docker.io/tripleomaster/centos-binary'
+            {'image_source': 'kolla',
+             'imagename': 'docker.io/tripleomaster/centos-binary'
                           '-neutron-server:current-tripleo'},
-            {'imagename': 'docker.io/tripleomaster/centos-binary'
+            {'image_source': 'kolla',
+             'imagename': 'docker.io/tripleomaster/centos-binary'
                           '-neutron-server-opendaylight:current-tripleo'},
-            {'imagename': 'docker.io/tripleomaster/centos-binary'
+            {'image_source': 'kolla',
+             'imagename': 'docker.io/tripleomaster/centos-binary'
                           '-opendaylight:current-tripleo'}]
         self._test_container_images_yaml_in_sync_helper(
             neutron_driver='ovn', remove_images=remove_images)
@@ -381,6 +547,7 @@ class TestPrepare(base.TestCase):
 
     def setUp(self):
         super(TestPrepare, self).setUp()
+        image_uploader.BaseImageUploader.init_registries_cache()
         with tempfile.NamedTemporaryFile(delete=False) as imagefile:
             self.addCleanup(os.remove, imagefile.name)
             self.filelist = [imagefile.name]
@@ -398,18 +565,26 @@ class TestPrepare(base.TestCase):
             kb.detect_insecure_registries(
                 {'foo': 'tripleo'}))
 
+    @mock.patch('requests.get')
+    def test_detect_insecure_registry_readtimeout(self, mock_get):
+
         mock_get.side_effect = requests.exceptions.ReadTimeout('ouch')
         self.assertEqual(
             {},
             kb.detect_insecure_registries(
                 {'foo': '192.0.2.0:8787/tripleo'}))
 
+    @mock.patch('requests.get')
+    def test_detect_insecure_registry_sslerror(self, mock_get):
         mock_get.side_effect = requests.exceptions.SSLError('ouch')
         self.assertEqual(
             {'DockerInsecureRegistryAddress': ['192.0.2.0:8787']},
             kb.detect_insecure_registries(
                 {'foo': '192.0.2.0:8787/tripleo'}))
 
+    @mock.patch('requests.get')
+    def test_detect_insecure_registry_multi(self, mock_get):
+        mock_get.side_effect = requests.exceptions.SSLError('ouch')
         self.assertEqual(
             {'DockerInsecureRegistryAddress': [
                 '192.0.2.0:8787',
@@ -431,7 +606,8 @@ class TestPrepare(base.TestCase):
     def test_prepare_simple(self, mock_get):
         self.assertEqual({
             'container_images.yaml': [
-                {'imagename': '192.0.2.0:8787/t/p-nova-compute:l'}
+                {'image_source': 'kolla',
+                 'imagename': '192.0.2.0:8787/t/p-nova-compute:l'}
             ],
             'environments/containers-default-parameters.yaml': {
                 'DockerNovaComputeImage': '192.0.2.0:8787/t/p-nova-compute:l',
@@ -457,7 +633,8 @@ class TestPrepare(base.TestCase):
     def test_prepare_includes(self, mock_get):
         self.assertEqual({
             'container_images.yaml': [
-                {'imagename': '192.0.2.0:8787/t/p-nova-libvirt:l'}
+                {'image_source': 'kolla',
+                 'imagename': '192.0.2.0:8787/t/p-nova-libvirt:l'}
             ],
             'environments/containers-default-parameters.yaml': {
                 'DockerNovaLibvirtImage': '192.0.2.0:8787/t/p-nova-libvirt:l'
@@ -481,7 +658,8 @@ class TestPrepare(base.TestCase):
         # assert same result as includes only. includes trumps excludes
         self.assertEqual({
             'container_images.yaml': [
-                {'imagename': '192.0.2.0:8787/t/p-nova-libvirt:l'}
+                {'image_source': 'kolla',
+                 'imagename': '192.0.2.0:8787/t/p-nova-libvirt:l'}
             ],
             'environments/containers-default-parameters.yaml': {
                 'DockerNovaLibvirtImage': '192.0.2.0:8787/t/p-nova-libvirt:l'
@@ -505,6 +683,7 @@ class TestPrepare(base.TestCase):
     def test_prepare_push_dest(self, mock_get):
         self.assertEqual({
             'container_images.yaml': [{
+                'image_source': 'kolla',
                 'imagename': 'docker.io/t/p-nova-api:l',
                 'push_destination': '192.0.2.0:8787',
             }],
@@ -539,6 +718,7 @@ class TestPrepare(base.TestCase):
         mock_gur.return_value = '192.0.2.0:8787'
         self.assertEqual({
             'container_images.yaml': [{
+                'image_source': 'kolla',
                 'imagename': 'docker.io/t/p-nova-api:l',
                 'push_destination': '192.0.2.0:8787',
             }],
@@ -571,6 +751,7 @@ class TestPrepare(base.TestCase):
     def test_prepare_ceph(self, mock_get):
         self.assertEqual({
             'container_images.yaml': [{
+                'image_source': 'ceph',
                 'imagename': '192.0.2.0:8787/t/ceph:l',
             }],
             'environments/containers-default-parameters.yaml': {
@@ -593,7 +774,8 @@ class TestPrepare(base.TestCase):
     def test_prepare_neutron_driver_default(self, mock_get):
         self.assertEqual({
             'container_images.yaml': [
-                {'imagename': 't/p-neutron-server:l'}
+                {'image_source': 'kolla',
+                 'imagename': 't/p-neutron-server:l'}
             ],
             'environments/containers-default-parameters.yaml': {
                 'DockerNeutronApiImage': 't/p-neutron-server:l',
@@ -620,8 +802,10 @@ class TestPrepare(base.TestCase):
     def test_prepare_neutron_driver_ovn(self, mock_get):
         self.assertEqual({
             'container_images.yaml': [
-                {'imagename': 't/p-neutron-server-ovn:l'},
-                {'imagename': 't/p-ovn-controller:l'}
+                {'image_source': 'kolla',
+                 'imagename': 't/p-neutron-server-ovn:l'},
+                {'image_source': 'kolla',
+                 'imagename': 't/p-ovn-controller:l'}
             ],
             'environments/containers-default-parameters.yaml': {
                 'DockerNeutronApiImage': 't/p-neutron-server-ovn:l',
@@ -651,8 +835,10 @@ class TestPrepare(base.TestCase):
     def test_prepare_neutron_driver_odl(self, mock_get):
         self.assertEqual({
             'container_images.yaml': [
-                {'imagename': 't/neutron-server-opendaylight:l'},
-                {'imagename': 't/opendaylight:l'}
+                {'image_source': 'kolla',
+                 'imagename': 't/neutron-server-opendaylight:l'},
+                {'image_source': 'kolla',
+                 'imagename': 't/opendaylight:l'}
             ],
             'environments/containers-default-parameters.yaml': {
                 'DockerNeutronApiImage': 't/neutron-server-opendaylight:l',
@@ -824,6 +1010,7 @@ class TestPrepare(base.TestCase):
         env = {
             'parameter_defaults': {
                 'LocalContainerRegistry': '192.0.2.1',
+                'DockerRegistryMirror': 'http://192.0.2.2/reg/',
                 'ContainerImagePrepare': [{
                     'set': mapping_args,
                     'tag_from_label': 'foo',
@@ -880,7 +1067,10 @@ class TestPrepare(base.TestCase):
                 append_tag=mock.ANY,
                 modify_role=None,
                 modify_only_with_labels=None,
-                modify_vars=None
+                modify_vars=None,
+                mirrors={
+                    'docker.io': 'http://192.0.2.2/reg/'
+                }
             ),
             mock.call(
                 excludes=['nova', 'neutron'],
@@ -895,7 +1085,10 @@ class TestPrepare(base.TestCase):
                 append_tag=mock.ANY,
                 modify_role='add-foo-plugin',
                 modify_only_with_labels=['kolla_version'],
-                modify_vars={'foo_version': '1.0.1'}
+                modify_vars={'foo_version': '1.0.1'},
+                mirrors={
+                    'docker.io': 'http://192.0.2.2/reg/'
+                }
             )
         ])
 
@@ -979,7 +1172,8 @@ class TestPrepare(base.TestCase):
                 append_tag=mock.ANY,
                 modify_role=None,
                 modify_only_with_labels=None,
-                modify_vars=None
+                modify_vars=None,
+                mirrors={}
             ),
             mock.call(
                 excludes=['nova', 'neutron'],
@@ -994,12 +1188,13 @@ class TestPrepare(base.TestCase):
                 append_tag=mock.ANY,
                 modify_role='add-foo-plugin',
                 modify_only_with_labels=['kolla_version'],
-                modify_vars={'foo_version': '1.0.1'}
+                modify_vars={'foo_version': '1.0.1'},
+                mirrors={}
             )
         ])
 
-        mock_im.assert_called_once_with(mock.ANY, dry_run=True, verbose=True,
-                                        cleanup='full')
+        mock_im.assert_called_once_with(mock.ANY, dry_run=True, cleanup='full',
+                                        mirrors={})
 
         self.assertEqual(
             {
