@@ -14,6 +14,7 @@
 
 import fixtures
 import os
+import sys
 import yaml
 
 from heatclient.exc import HTTPNotFound
@@ -171,20 +172,6 @@ class TestInventory(base.TestCase):
     def test_inventory_list(self):
         self._inventory_list(self.inventory)
 
-    def test_inventory_list_backwards_compat_configs(self):
-        # FIXME(shardy) backwards compatibility until we switch
-        # tripleo-validations to pass the individual values
-        configs = MagicMock()
-        configs.plan = self.plan_name
-        configs.auth_url = 'xyz://keystone.local'
-        configs.cacert = 'acacert'
-        configs.project_name = 'admin'
-        configs.username = 'admin'
-        configs.ansible_ssh_user = 'heat-admin'
-        inventory = TripleoInventory(
-            configs, self.session, self.hclient)
-        self._inventory_list(inventory)
-
     def _inventory_list(self, inventory):
         ansible_ssh_user = 'heat-admin'
         expected = {
@@ -213,6 +200,7 @@ class TestInventory(base.TestCase):
                 'hosts': ['undercloud'],
                 'vars': {'ansible_connection': 'local',
                          'ansible_host': 'localhost',
+                         'ansible_python_interpreter': sys.executable,
                          'ansible_remote_tmp': '/tmp/ansible-${USER}',
                          'auth_url': 'xyz://keystone.local',
                          'cacert': 'acacert',
@@ -253,24 +241,28 @@ class TestInventory(base.TestCase):
             project_name='admin',
             username='admin',
             cacert='acacert',
-            ansible_ssh_user=ansible_ssh_user)
+            ansible_ssh_user=ansible_ssh_user,
+            ansible_python_interpreter='foo')
 
         self.inventory.stack_outputs = self.outputs
 
         expected = {
             'Compute': {
                 'hosts': ['cp-0'],
-                'vars': {'ansible_ssh_user': ansible_ssh_user,
+                'vars': {'ansible_python_interpreter': 'foo',
+                         'ansible_ssh_user': ansible_ssh_user,
                          'bootstrap_server_id': 'a',
                          'tripleo_role_name': 'Compute'}},
             'Controller': {
                 'hosts': ['c-0', 'c-1', 'c-2'],
-                'vars': {'ansible_ssh_user': ansible_ssh_user,
+                'vars': {'ansible_python_interpreter': 'foo',
+                         'ansible_ssh_user': ansible_ssh_user,
                          'bootstrap_server_id': 'a',
                          'tripleo_role_name': 'Controller'}},
             'CustomRole': {
                 'hosts': ['cs-0'],
-                'vars': {'ansible_ssh_user': ansible_ssh_user,
+                'vars': {'ansible_python_interpreter': 'foo',
+                         'ansible_ssh_user': ansible_ssh_user,
                          'bootstrap_server_id': 'a',
                          'tripleo_role_name': 'CustomRole'}},
             'overcloud': {
@@ -282,6 +274,7 @@ class TestInventory(base.TestCase):
                 'hosts': ['undercloud'],
                 'vars': {'ansible_connection': 'local',
                          'ansible_host': 'localhost',
+                         'ansible_python_interpreter': 'foo',
                          'ansible_remote_tmp': '/tmp/ansible-${USER}',
                          'auth_url': 'xyz://keystone.local',
                          'cacert': 'acacert',
@@ -379,6 +372,8 @@ class TestInventory(base.TestCase):
             'Undercloud': {'hosts': {'undercloud': {}},
                            'vars': {'ansible_connection': 'local',
                                     'ansible_host': 'localhost',
+                                    'ansible_python_interpreter':
+                                        sys.executable,
                                     'ansible_remote_tmp':
                                         '/tmp/ansible-${USER}',
                                     'auth_url': 'xyz://keystone.local',
